@@ -1,3 +1,22 @@
+# ====================================================================
+#    Licensed to the Apache Software Foundation (ASF) under one
+#    or more contributor license agreements.  See the NOTICE file
+#    distributed with this work for additional information
+#    regarding copyright ownership.  The ASF licenses this file
+#    to you under the Apache License, Version 2.0 (the
+#    "License"); you may not use this file except in compliance
+#    with the License.  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing,
+#    software distributed under the License is distributed on an
+#    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#    KIND, either express or implied.  See the License for the
+#    specific language governing permissions and limitations
+#    under the License.
+# ====================================================================
+
 require "my-assertions"
 require "util"
 
@@ -315,7 +334,7 @@ class SvnClientTest < Test::Unit::TestCase
     file = "sample.txt"
     deep_dir_path = File.join(@wc_path, deep_dir)
     path = File.join(deep_dir_path, file)
-    tmp_deep_dir_path = File.join(@tmp_path, deep_dir)
+    tmp_deep_dir_path = File.join(@import_path, deep_dir)
     tmp_path = File.join(tmp_deep_dir_path, file)
 
     make_context(log) do |ctx|
@@ -323,7 +342,7 @@ class SvnClientTest < Test::Unit::TestCase
       FileUtils.mkdir_p(tmp_deep_dir_path)
       File.open(tmp_path, "w") {|f| f.print(src)}
 
-      ctx.import(@tmp_path, @repos_uri)
+      ctx.import(@import_path, @repos_uri)
 
       ctx.up(@wc_path)
       assert_equal(src, File.open(path){|f| f.read})
@@ -337,7 +356,7 @@ class SvnClientTest < Test::Unit::TestCase
     file = "sample.txt"
     deep_dir_path = File.join(@wc_path, deep_dir)
     path = File.join(deep_dir_path, file)
-    tmp_deep_dir_path = File.join(@tmp_path, deep_dir)
+    tmp_deep_dir_path = File.join(@import_path, deep_dir)
     tmp_path = File.join(tmp_deep_dir_path, file)
 
     make_context(log) do |ctx|
@@ -345,7 +364,7 @@ class SvnClientTest < Test::Unit::TestCase
       FileUtils.mkdir_p(tmp_deep_dir_path)
       File.open(tmp_path, "w") {|f| f.print(src)}
 
-      new_rev = ctx.import(@tmp_path, @repos_uri, true, false,
+      new_rev = ctx.import(@import_path, @repos_uri, true, false,
                            {"custom-prop" => "some-value"}).revision
       assert_equal(["some-value", new_rev],
                    ctx.revprop_get("custom-prop", @repos_uri, new_rev))
@@ -500,20 +519,26 @@ class SvnClientTest < Test::Unit::TestCase
     path = File.join(dir_path, file)
     content = "Hello"
 
+    wc_path2 = @wc_path + '2'
+    path2 = File.join(wc_path2, dir, file)
+    wc_path3 = @wc_path + '3'
+    path3 = File.join(wc_path3, dir, file)
+
     make_context(log) do |ctx|
       ctx.mkdir(dir_path)
       File.open(path, "w"){|f| f.print(content)}
       ctx.add(path)
       ctx.commit(@wc_path)
 
-      FileUtils.rm_rf(@wc_path)
-      ctx.checkout(@repos_uri, @wc_path)
-      assert(File.exist?(path))
+      ctx.checkout(@repos_uri, wc_path2)
+      assert(File.exist?(path2))
 
-      FileUtils.rm_rf(@wc_path)
-      ctx.co(@repos_uri, @wc_path, nil, nil, false)
-      assert(!File.exist?(path))
+      ctx.co(@repos_uri, wc_path3, nil, nil, false)
+      assert(!File.exist?(path3))
     end
+  ensure
+    remove_recursively_with_retry(wc_path3)
+    remove_recursively_with_retry(wc_path2)
   end
 
   def test_update
@@ -991,29 +1016,39 @@ class SvnClientTest < Test::Unit::TestCase
       end
       assert_equal_log_entries([
                                 [
-                                 {branch_path_relative_uri => ["D", nil, -1]},
-                                 rev4,
+                                 {branch_path_relative_uri => ["M", nil, -1]},
+                                 rev2,
                                  {
                                    "svn:author" => @author,
                                    "svn:log" => log,
                                  },
                                  false,
                                 ]
-                               ] * 2, merged_entries)
+                               ], merged_entries)
 
       ctx.propdel("svn:mergeinfo", trunk)
       merged_entries = []
       ctx.log_merged(trunk, rev4, branch_uri, rev4) do |entry|
         merged_entries << entry
       end
-      assert_equal_log_entries([], merged_entries)
+      assert_equal_log_entries([
+                                [
+                                 {branch_path_relative_uri => ["M", nil, -1]},
+                                 rev2,
+                                 {
+                                   "svn:author" => @author,
+                                   "svn:log" => log,
+                                 },
+                                 false,
+                                ]
+                               ], merged_entries)
 
       ctx.revert(trunk)
       File.open(trunk_path, "a") {|f| f.print(src)}
       yield(ctx, branch, rev3, rev4, trunk)
       ctx.revert(trunk, false)
       ctx.resolve(:path=>trunk_path,
-                  :conflict_choice=>Svn::Wc::CONFLICT_CHOOSE_MINE_FULL)
+                  :conflict_choice=>Svn::Wc::CONFLICT_CHOOSE_MERGED)
       rev5 = ctx.commit(@wc_path).revision
       assert(File.exist?(trunk_path))
       ctx.up(@wc_path)
@@ -1044,6 +1079,12 @@ class SvnClientTest < Test::Unit::TestCase
     end
   end
 
+=begin
+  We haven't yet figured out what to expect in the case of an obstruction,
+  but it is no longer an error.  Commenting out this test until that
+  decision is made (see issue #3680:
+  http://subversion.tigris.org/issues/show_bug.cgi?id=3680)
+
   def test_cleanup
     log = "sample log"
     file = "sample.txt"
@@ -1081,18 +1122,15 @@ class SvnClientTest < Test::Unit::TestCase
       end
 
       ctx.set_cancel_func(nil)
-      access = Svn::Wc::AdmAccess.open(nil, @wc_path, true, -1)
       assert_nothing_raised do
         ctx.cleanup(@wc_path)
       end
       assert_nothing_raised do
         ctx.commit(@wc_path)
       end
-      assert_raises(Svn::Error::SvnError) do
-        access.close
-      end
     end
   end
+=end
 
   def test_relocate
     log = "sample log"
@@ -1249,7 +1287,6 @@ class SvnClientTest < Test::Unit::TestCase
         ctx.mv(path1, path2)
       end
       ctx.revert([path1, path2])
-      FileUtils.rm(path2)
 
       File.open(path1, "w") {|f| f.print(src2)}
       assert_nothing_raised do
@@ -2052,7 +2089,7 @@ class SvnClientTest < Test::Unit::TestCase
     assert_simple_provider(:add_simple_provider)
   end
 
-  if Svn::Core.respond_to?(:auth_get_windows_simple_provider)
+  if Svn::Client::Context.method_defined?(:add_windows_simple_provider)
     def test_windows_simple_provider
       assert_simple_provider(:add_windows_simple_provider)
     end
@@ -2166,7 +2203,10 @@ class SvnClientTest < Test::Unit::TestCase
 
     make_context(log) do |ctx|
       items = nil
-      ctx.set_log_msg_func do |items|
+      ctx.set_log_msg_func do |l_items|
+        # ruby 1.8 will carry the assignment of items out of the
+        # scope of this block, 1.9 will not, so we must assign.
+        items = l_items
         [true, log]
       end
 
@@ -2256,43 +2296,44 @@ class SvnClientTest < Test::Unit::TestCase
       ctx.commit(@wc_path)
 
       assert_equal({}, yield(ctx, changelist1))
-      assert_equal({nil=>[@wc_path,path1,path2]}, yield(ctx, nil))
+      assert_equal({nil=>[@wc_path,path1,path2].map{|f| File.expand_path(f)}}, yield(ctx, nil))
       assert_equal({}, yield(ctx, []))
       assert_equal({}, yield(ctx, [changelist1]))
       assert_equal({}, yield(ctx, [changelist2]))
       ctx.add_to_changelist(changelist1, path1)
-      assert_equal({changelist1=>[path1]}, yield(ctx, changelist1))
-      assert_equal({changelist1=>[path1],nil=>[@wc_path,path2]}, yield(ctx, nil))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)}}, yield(ctx, changelist1))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)},nil=>[@wc_path,path2].map{|f| File.expand_path(f)}}, yield(ctx, nil))
       assert_equal({}, yield(ctx, []))
-      assert_equal({changelist1=>[path1]}, yield(ctx, [changelist1]))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)}}, yield(ctx, [changelist1]))
       assert_equal({}, yield(ctx, [changelist2]))
 
       assert_equal({}, yield(ctx, changelist2))
       ctx.add_to_changelist(changelist2, [path1, path2])
-      assert_equal({changelist2=>[path1, path2]}, yield(ctx, changelist2))
+      assert_equal({changelist2=>[path1, path2].map{|f| File.expand_path(f)}}, yield(ctx, changelist2))
       assert_equal({}, yield(ctx, changelist1))
 
       ctx.add_to_changelist(changelist1, [path1, path2])
-      assert_equal({changelist1=>[path1, path2]}, yield(ctx, changelist1))
+      assert_equal({changelist1=>[path1, path2].map{|f| File.expand_path(f)}}, yield(ctx, changelist1))
       assert_equal({}, yield(ctx, changelist2))
 
       ctx.remove_from_changelists(changelist1, path1)
-      assert_equal({changelist1=>[path2]}, yield(ctx, changelist1))
+      assert_equal({changelist1=>[path2].map{|f| File.expand_path(f)}}, yield(ctx, changelist1))
       ctx.remove_from_changelists(changelist1, [path2])
       assert_equal({}, yield(ctx, changelist1))
 
       ctx.add_to_changelist(changelist1, path1)
       ctx.add_to_changelist(changelist2, path2)
-      assert_equal({changelist1=>[path1]}, yield(ctx, changelist1))
-      assert_equal({changelist2=>[path2]}, yield(ctx, changelist2))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)}}, yield(ctx, changelist1))
+      assert_equal({changelist2=>[path2].map{|f| File.expand_path(f)}}, yield(ctx, changelist2))
 
-      assert_equal({changelist1=>[path1]}, yield(ctx, changelist1))
-      assert_equal({changelist2=>[path2]}, yield(ctx, changelist2))
-      assert_equal({changelist1=>[path1]}, yield(ctx, [changelist1]))
-      assert_equal({changelist2=>[path2]}, yield(ctx, [changelist2]))
-      assert_equal({changelist1=>[path1],changelist2=>[path2],nil=>[@wc_path]}, yield(ctx, nil))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)}}, yield(ctx, changelist1))
+      assert_equal({changelist2=>[path2].map{|f| File.expand_path(f)}}, yield(ctx, changelist2))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)}}, yield(ctx, [changelist1]))
+      assert_equal({changelist2=>[path2].map{|f| File.expand_path(f)}}, yield(ctx, [changelist2]))
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)},changelist2=>[path2].map{|f| File.expand_path(f)},nil=>[@wc_path].map{|f| File.expand_path(f)}},
+		   yield(ctx, nil))
       assert_equal({}, yield(ctx, []))
-      assert_equal({changelist1=>[path1],changelist2=>[path2]},
+      assert_equal({changelist1=>[path1].map{|f| File.expand_path(f)},changelist2=>[path2].map{|f| File.expand_path(f)}},
                    yield(ctx, [changelist1,changelist2]))
 
       ctx.remove_from_changelists(nil, [path1, path2])
@@ -2303,7 +2344,9 @@ class SvnClientTest < Test::Unit::TestCase
 
   def test_changelists_get_without_block
     assert_changelists do |ctx, changelist_name|
-      ctx.changelists(changelist_name, @wc_path)
+      changelists = ctx.changelists(changelist_name, @wc_path)
+      changelists.each_value { |v| v.sort! }
+      changelists
     end
   end
 
@@ -2313,6 +2356,7 @@ class SvnClientTest < Test::Unit::TestCase
       ctx.changelists(changelist_name, @wc_path) do |path,cl_name|
         changelists[cl_name] << path
       end
+      changelists.each_value { |v| v.sort! }
       changelists
     end
   end
@@ -2371,7 +2415,7 @@ class SvnClientTest < Test::Unit::TestCase
         ctx.ci(@wc_path)
       end
 
-      ctx.resolve(:path=>dir_path, :depth=>:infinite, :conflict_choice=>choice)
+      ctx.resolve(:path=>dir_path, :depth=>:infinity, :conflict_choice=>choice)
       yield ctx, path
     end
   end
